[![Multi-Modality](agorabanner.png)](https://discord.gg/qUtxnK2NMf)

# MMCA-MGQA
Experiments around using Multi-Modal Casual Attention with Multi-Grouped Query Attention


# Appreciation
* Lucidrains
* Agorians


# Install
`pip install mmca-mgqa`

# Usage

# Architecture

# Todo


# License
MIT
